==> liblxqt_0.14.1.1+rb2.orig.tar.xz: liblxqt-0.14.1.1+rb2/translations/liblxqt_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogas</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt maitinimo tvarkytuvės klaida</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="74"/>
        <source>Hibernate failed.</source>
        <translation>Užmigdymas nepavyko.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation>Pranešimų surogatas</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="117"/>
        <source>Hibernate</source>
        <translation>Užmigdyti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="124"/>
        <source>Suspend</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="131"/>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="138"/>
        <source>Shutdown</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="145"/>
        <source>Logout</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="157"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQt seanso pristabdymas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Ar tikrai norite pristabdyti savo kompiuterį?&lt;p&gt;Pristabdo kompiuterį į mažo energijos naudojimo būseną. Nutrūkus maitinimui, sistemos būsena nėra išsaugoma.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="167"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQt seanso užmigdymas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Ar tikrai norite užmigdyti savo kompiuterį?&lt;p&gt;Užmigdo kompiuterį į mažo energijos naudojimo būseną. Nutrūkus maitinimui, sistemos būsena yra išsaugoma.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="177"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt seanso paleidimas iš naujo</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Ar tikrai norite paleisti savo kompiuterį iš naujo? Visas neįrašytas darbas bus prarastas...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="187"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt seanso išjungimas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Ar tikrai norite išjungti savo kompiuterį? Visas neįrašytas darbas bus prarastas...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>LXQt Session Logout</source>
        <translation>LXQt seanso atjungimas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Ar tikrai norite atsijungti? Visas neįrašytas darbas bus prarastas...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt maitinimo tvarkytuvės klaida</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="206"/>
        <source>Hibernate failed.</source>
        <translation>Užmigdymas nepavyko.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="211"/>
        <source>Suspend failed.</source>
        <translation>Pristabdymas nepavyko.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="236"/>
        <source>Lock Screen</source>
        <translation>Užrakinti ekraną</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Ekrano užsklandos klaida</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="157"/>
        <source>An error occurred starting screensaver. Syntax error in xdg-screensaver arguments.</source>
        <translation>Paleidžiant ekrano užsklandą, įvyko klaida. Sintaksės klaida xdg-screensaver argumentuose.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="162"/>
        <location filename="../lxqtscreensaver.cpp" line="168"/>
        <location filename="../lxqtscreensaver.cpp" line="175"/>
        <source>Screen Saver Activation Error</source>
        <translation>Ekrano užsklandos aktyvavimo klaida</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="163"/>
        <source>An error occurred starting screensaver. Ensure you have xscreensaver installed and running.</source>
        <translation>Paleidžiant ekrano užsklandą, įvyko klaida. Įsitikinkite, kad esate įdiegę ir paleidę xscreensaver.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="169"/>
        <source>An error occurred starting screensaver. Action &apos;activate&apos; failed. Ensure you have xscreensaver installed and running.</source>
        <translation>Paleidžiant ekrano užsklandą, įvyko klaida. Veiksmas &quot;activate&quot; nepavyko. Įsitikinkite, kad esate įdiegę ir paleidę xscreensaver.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="176"/>
        <source>An error occurred starting screensaver. Unknown error - undocumented return value from xdg-screensaver: %1.</source>
        <translation>Paleidžiant ekrano užsklandą, įvyko klaida. Nežinoma klaida - nedokumentuota grąžinimo reikšmė iš xdg-screensaver: %1.</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Pasirinkite puslapį, kuris bus rodomas.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Maitinimo tvarkytuvės klaida</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface yra netaisyklinga</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Maitinimo tvarkytuvės klaida (D-BUS iškvieta)</translation>
    </message>
</context>
</TS>

==> liblxqt_0.15.0.orig.tar.xz: liblxqt-0.15.0/translations/liblxqt_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogas</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt maitinimo tvarkytuvės klaida</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="75"/>
        <source>Hibernate failed.</source>
        <translation>Užmigdymas nepavyko.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="154"/>
        <source>Notifications Fallback</source>
        <translation>Pranešimų surogatas</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="118"/>
        <source>Hibernate</source>
        <translation>Užmigdyti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="125"/>
        <source>Suspend</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="132"/>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="139"/>
        <source>Shutdown</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="146"/>
        <source>Logout</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Suspend</source>
        <translation>LXQt seanso pristabdymas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Ar tikrai norite pristabdyti savo kompiuterį?&lt;p&gt;Pristabdo kompiuterį į mažo energijos naudojimo būseną. Nutrūkus maitinimui, sistemos būsena nėra išsaugoma.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Hibernate</source>
        <translation>LXQt seanso užmigdymas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Ar tikrai norite užmigdyti savo kompiuterį?&lt;p&gt;Užmigdo kompiuterį į mažo energijos naudojimo būseną. Nutrūkus maitinimui, sistemos būsena yra išsaugoma.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Reboot</source>
        <translation>LXQt seanso paleidimas iš naujo</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Ar tikrai norite paleisti savo kompiuterį iš naujo? Visas neįrašytas darbas bus prarastas...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Shutdown</source>
        <translation>LXQt seanso išjungimas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Ar tikrai norite išjungti savo kompiuterį? Visas neįrašytas darbas bus prarastas...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="198"/>
        <source>LXQt Session Logout</source>
        <translation>LXQt seanso atjungimas</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="199"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Ar tikrai norite atsijungti? Visas neįrašytas darbas bus prarastas...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>LXQt Power Manager Error</source>
        <translation>LXQt maitinimo tvarkytuvės klaida</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="207"/>
        <source>Hibernate failed.</source>
        <translation>Užmigdymas nepavyko.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="212"/>
        <source>Suspend failed.</source>
        <translation>Pristabdymas nepavyko.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="161"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>Nepavyko paleisti &quot;%1&quot;. Įsitikinkite, kad esate įdiegę ir paleidę su xdg-screensaver suderinamą užrakto įrankį/ekrano užsklandą.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="165"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>Nepavyko paleisti &quot;%1&quot;. Įsitikinkite, kad nurodytas užrakto įrankis/ekrano užsklanda yra įdiegta ir veikia.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="243"/>
        <source>Lock Screen</source>
        <translation>Užrakinti ekraną</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Ekrano užsklandos klaida</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Pasirinkite puslapį, kuris bus rodomas.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Maitinimo tvarkytuvės klaida</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface yra netaisyklinga</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Maitinimo tvarkytuvės klaida (D-BUS iškvieta)</translation>
    </message>
</context>
</TS>
